@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-stock-icons.h 7119 2007-07-09 16:37:50Z chpe $
+ *  $Id$
  */
 
 #ifndef EPHY_STOCK_ICONS_H
@@ -23,25 +23,26 @@
 
 G_BEGIN_DECLS
 
-#define EPHY_STOCK_EPHY		   "web-browser"
+#define EPHY_STOCK_EPHY            "gnome-web-browser"
 
 /* Custom Epiphany named icons */
-#define EPHY_STOCK_POPUPS	   "popup-hidden"
+#define EPHY_STOCK_POPUPS          "popup-hidden"
 #define EPHY_STOCK_HISTORY         "history-view"
 #define EPHY_STOCK_BOOKMARK        "bookmark-web"
 #define EPHY_STOCK_BOOKMARKS       "bookmark-view"
-#define EPHY_STOCK_ENTRY	   "location-entry"
-#define EPHY_STOCK_DOWNLOAD	   "download"
+#define EPHY_STOCK_ENTRY           "location-entry"
 #define STOCK_LOCK_INSECURE        "lock-insecure"
 #define STOCK_LOCK_SECURE          "lock-secure"
-#define STOCK_LOCK_BROKEN	   "lock-broken"
+#define STOCK_LOCK_BROKEN          "lock-broken"
 
 /* Named icons defined in fd.o Icon Naming Spec */
 #define STOCK_NEW_TAB              "tab-new"
 #define STOCK_NEW_WINDOW           "window-new"
 #define STOCK_SEND_MAIL            "mail-forward"
+#define STOCK_NEW_MAIL             "mail-message-new"
 #define STOCK_ADD_BOOKMARK         "bookmark-new"
 #define STOCK_PRINT_SETUP          "document-page-setup"
+#define STOCK_DOWNLOAD             "emblem-downloads"
 
 void ephy_stock_icons_init (void);
 
